@@ -11,7 +11,7 @@ package IOas::CP932X;
 use 5.00503;    # Galapagos Consensus 1998 for primetools
 # use 5.008001; # Lancaster Consensus 2013 for toolchains
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 $VERSION = $VERSION;
 
 use strict;
@@ -92,10 +92,10 @@ sub gt  ($$) { _io_output($_[0]) gt  _io_output($_[1]) }
 sub le  ($$) { _io_output($_[0]) le  _io_output($_[1]) }
 sub lt  ($$) { _io_output($_[0]) lt  _io_output($_[1]) }
 sub sort (@) {
-    return map { $_->[0] }
-        CORE::sort { $a->[1] cmp $b->[1] }
-        map { [ $_, _io_output($_) ] }
-        @_;
+    map { $_->[0] }
+    CORE::sort { $a->[1] cmp $b->[1] }
+    map { [ $_, _io_output($_) ] }
+    @_;
 }
 
 #-----------------------------------------------------------------------------
@@ -104,11 +104,19 @@ sub sort (@) {
 
 sub getc (;*) {
     my $fh = @_ ? Symbol::qualify_to_ref($_[0],caller()) : \*STDIN;
-    my @octet = CORE::getc($fh);
-    if ($octet[0] =~ /\A[\x81-\x9F\xE0-\xFC]\z/) {
-        push @octet, CORE::getc($fh);
+    my $octet = CORE::getc($fh);
+    if ($io_encoding =~ /^(?:cp932x|cp932|cp932ibm|cp932nec|sjis2004)$/) {
+        if ($octet =~ /\A[\x81-\x9F\xE0-\xFC]\z/) {
+            $octet .= CORE::getc($fh);
+
+            # ('cp932'.'x') to escape from build system
+            if (($io_encoding eq ('cp932'.'x')) and ($octet eq "\x9C\x5A")) {
+                $octet .= CORE::getc($fh);
+                $octet .= CORE::getc($fh);
+            }
+        }
     }
-    return _io_input(join '', @octet);
+    return _io_input($octet);
 }
 
 sub readline (;*) {
@@ -154,11 +162,12 @@ IOas::CP932X - provides CP932X I/O subroutines for UTF-8 script
     $result = IOas::CP932X::gt($utf8str_a, $utf8str_b);
     $result = IOas::CP932X::le($utf8str_a, $utf8str_b);
     $result = IOas::CP932X::lt($utf8str_a, $utf8str_b);
-    $result = IOas::CP932X::sort(@utf8str);
+    @result = IOas::CP932X::sort(@utf8str);
 
     # Encoding Convert on I/O Operations
     $result = IOas::CP932X::getc(FILEHANDLE);
     $result = IOas::CP932X::readline(FILEHANDLE);
+    @result = IOas::CP932X::readline(FILEHANDLE);
     $result = IOas::CP932X::print(FILEHANDLE, @utf8str);
     $result = IOas::CP932X::printf(FILEHANDLE, $utf8format, @utf8list);
 
